@@ -21,6 +21,9 @@ class RunningScenario(object):
     def started_at(self) -> datetime:
         return self._started_at
 
+    def ended_at(self) -> datetime:
+        return self._stopped_at
+
     def has_modifiers(self):
         return bool(self._modifiers)
 
@@ -33,9 +36,6 @@ class RunningScenario(object):
     def is_running(self):
         return self._stopped_at is None
 
-    def ended_at(self):
-        return self._stopped_at
-
 
 class Simulation:
     """
@@ -81,10 +81,14 @@ class Simulation:
 
         return self.running_scenario().modifiers()
 
-    def stop_running_scenario(self):
+    def stop_running_scenario(self) -> RunningScenario:
         assert self.scenario_is_running(), "No scenario is running"
 
-        self.running_scenario().end()
+        scenario = self.running_scenario()
+
+        scenario.end()
+
+        return scenario
 
     def stop(self):
         if not self.is_running():
