@@ -1,4 +1,3 @@
-from collections import defaultdict
 from datetime import datetime
 from functools import wraps
 import time
@@ -18,21 +17,21 @@ cpu_percents_measurements = []
 latency_measurements = {}
 
 
-def add_regression_wrapper(app, endpoint_name):
+def add_modifier_wrapper(app, endpoint_name):
     f = app.view_functions[endpoint_name]
 
     @wraps(f)
     def wrapper(*args, **kwargs):
-        relevant_regressions = [c for c in simulation.current_modifiers() if c['endpoint_name'] == endpoint_name]
+        relevant_modifiers = [c for c in simulation.current_modifiers() if c['endpoint_name'] == endpoint_name]
 
         new_f = f
-        for regression in relevant_regressions:
-            regression_type = regression['type']
+        for modifier in relevant_modifiers:
+            regression_type = modifier['type']
 
             apply = [c for c in registered_modifier_types if c.identifier() == regression_type]
 
             for a in apply:
-                new_f = a.modify(f, endpoint_name, regression['args'])
+                new_f = a.modify(f, endpoint_name, modifier['args'])
 
         return new_f(*args, **kwargs)
 
@@ -97,5 +96,5 @@ def initialise_scenario_testing(app: Flask, modifier_types: [Modifier]):
         if endpoint_name.startswith('scenario-testing'):
             continue
 
-        add_regression_wrapper(app, endpoint_name)
+        add_modifier_wrapper(app, endpoint_name)
         add_latency_tracking_wrapper(app, endpoint_name)
